<?php
$translations = array(
	'General_Locale' => 'lv_LV.UTF-8',
	'General_TranslatorName' => 'Ēriks Remess',
	'General_TranslatorEmail' => 'piwik@apps.lv',
	'General_EnglishLanguageName' => 'Latvian',
	'General_OriginalLanguageName' => 'Latviešu',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Sveiki, %s!',
	'General_OpenSourceWebAnalytics' => 'Atvērtā koda tīkla analīze',
	'General_Dashboard' => 'Panelis',
	'General_DashboardForASpecificWebsite' => 'Izvēlētas vietnes panelis',
	'General_MultiSitesSummary' => 'Visas vietnes',
	'General_AllWebsitesDashboard' => 'Visu vietņu panelis',
	'General_API' => 'API',
	'General_Widgets' => 'Logdaļas',
	'General_Settings' => 'Iestatījumi',
	'General_GiveUsYourFeedback' => 'Rakstiet mums atsauksmes!',
	'General_Unknown' => 'Nezināms',
	'General_Never' => 'Nekad',
	'General_Required' => '%s nepieciešams',
	'General_NotValid' => '%s nekorekts',
	'General_NotDefined' => '%s nav definēts',
	'General_Id' => 'Id',
	'General_Error' => 'Kļūda',
	'General_Warning' => 'Brīdinājums',
	'General_BackToHomepage' => 'Atpakaļ uz Piwik sākumlapu',
	'General_Yes' => 'Jā',
	'General_No' => 'Nē',
	'General_Delete' => 'Dzēst',
	'General_Report' => 'Ziņot',
	'General_Reports' => 'Atskaites',
	'General_Edit' => 'Labot',
	'General_Download' => 'Lejupielādēt',
	'General_Upload' => 'Augšuplādēt',
	'General_Ok' => 'Labi',
	'General_Close' => 'Aizvērt',
	'General_OrCancel' => 'vai %s atcelt %s',
	'General_Logout' => 'Iziet',
	'General_Username' => 'Lietotājvārds',
	'General_Description' => 'Apraksts',
	'General_Done' => 'Pabeigts',
	'General_PoweredBy' => 'Darbina',
	'General_MetricsToPlot' => 'Mērījumi plānošanai',
	'General_RowsToDisplay' => 'Rindas parādīšanai',
	'General_MetricToPlot' => 'Mērījums plānošanai',
	'General_RecordsToPlot' => 'Ieraksti plānošanai',
	'General_Name' => 'Vārds',
	'General_Value' => 'Vērtība',
	'General_Total' => 'Kopā',
	'General_AverageOrderValue' => 'Vidējā pasūtījuma vērtība',
	'General_PurchasedProducts' => 'Iegādātie produkti',
	'General_EcommerceOrders' => 'E-komercijas pasūtījumi',
	'General_AbandonedCarts' => 'Pamestie iepirkumu grozi',
	'General_TotalRevenue' => 'Kopējie ienākumi',
	'General_ProductRevenue' => 'Ienākumi no produkta',
	'General_AveragePrice' => 'Vidējā cena',
	'General_AverageQuantity' => 'Vidējais apjoms',
	'General_UniquePurchases' => 'Unikāli pirkumi',
	'General_ProductConversionRate' => 'Produktu konversijas likme',
	'General_Quantity' => 'Skaits',
	'General_Price' => 'Cena',
	'General_Subtotal' => 'Starpsumma',
	'General_Tax' => 'Nodokļi',
	'General_Shipping' => 'Piegāde',
	'General_Discount' => 'Atlaide',
	'General_Details' => 'Sīkāka informācija',
	'General_Default' => 'Noklusējuma',
	'General_Visit' => 'Apmeklējums',
	'General_FromReferrer' => 'no',
	'General_VisitorIP' => 'Apmeklētāja IP',
	'General_VisitorID' => 'Apmeklētāja ID',
	'General_VisitType' => 'Apmeklētāja tips',
	'General_VisitTypeExample' => 'Piemēram, lai izvēlētos visus apmeklētājus, kas atgriezušies vietnē (ieskaitot tos, kas veikuši pasūtījumu kādā no iepriekšējiem apmeklējumiem), API pieprasījumam būtu jāsatur %s',
	'General_DaysSinceLastVisit' => 'Dienas kopš pēdējā apmeklējuma',
	'General_DaysSinceFirstVisit' => 'Dienas kopš pirmā apmeklējuma',
	'General_DaysSinceLastEcommerceOrder' => 'Dienas kopš pēdējā e-komercijas pasūtījuma',
	'General_NumberOfVisits' => 'Apmeklējumu skaits',
	'General_VisitConvertedGoal' => 'Apmeklējums sasniedza vismaz vienu mērķi',
	'General_VisitConvertedGoalId' => 'Apmeklējums sasniedza konkrētu mērķi ar Id',
	'General_EcommerceVisitStatus' => 'Apmeklējuma e-komercijas statuss apmeklējuma beigās. Piemēra, lai izvēlētos visus apmeklējumus, kuros tikai veikts e-komercijas pasūtījums, API pieprasījums saturētu %s',
	'General_VisitConvertedNGoals' => 'Apmeklējums sasniedza %s mērķus',
	'General_NewVisitor' => 'Jauns apmeklētājs',
	'General_NewVisits' => 'Jauni apmeklējumi',
	'General_ReturningVisitor' => 'Atkārtots apmeklētājs',
	'General_Visitor' => 'Apmeklētājs',
	'General_Date' => 'Datums',
	'General_Period' => 'Periods',
	'General_ChooseDate' => 'Izvēlies datumu',
	'General_Today' => 'Šodien',
	'General_Yesterday' => 'Vakar',
	'General_CurrentWeek' => 'Pašreizējā nedēļa',
	'General_CurrentMonth' => 'Pašreizējais mēnesis',
	'General_CurrentYear' => 'Pašreizējais gads',
	'General_DateRange' => 'Datumu diapazons:',
	'General_DateRangeInPeriodList' => 'Datumu diapazons',
	'General_DateRangeFromTo' => 'No %s līdz %s',
	'General_ApplyDateRange' => 'Apstiprināt datumu diapozonu',
	'General_InvalidDateRange_js' => 'Nepareizs datumu diapozons, mēģinien no jauna',
	'General_DateRangeFrom_js' => 'No',
	'General_DateRangeTo_js' => 'Līdz',
	'General_PreviousDays' => 'Iepriekšējās %s dienas (neskaitot šodienu)',
	'General_LastDays' => 'Pēdējās %s dienas (ieskaitot šodienu)',
	'General_LoadingData' => 'Ielādē datus...',
	'General_Loading_js' => 'Ielāde...',
	'General_GoTo' => 'Iet uz %s',
	'General_Next' => 'Nākamā',
	'General_Previous' => 'Iepriekšējā',
	'General_First' => 'Pirmais',
	'General_Search' => 'Meklēt',
	'General_Others' => 'Citi',
	'General_Table' => 'Tabula',
	'General_Piechart' => 'Sektoru diagramma',
	'General_TagCloud' => 'Tagu mākonis',
	'General_VBarGraph' => 'Vertikālo joslu diagramma',
	'General_View' => 'Skatījums',
	'General_OpenInNewWindow_js' => 'Atvērt jaunā logā',
	'General_SaveImageOnYourComputer_js' => 'Lai saglabātu bildi datora, uz bildes spiediet labo peles pogu un izvēlieties "Save Image As..."',
	'General_Refresh' => 'Atsvaidzināt lapu',
	'General_Visitors' => 'Apmeklētāji',
	'General_ExportThisReport' => 'Eksportēt šo datu kopu citos formātos',
	'General_ExportAsImage_js' => 'Eksportēt kā bildi',
	'General_Export' => 'Eksports',
	'General_ParameterMustIntegerBetween' => 'Parametra %s vērtībai ir jābūt skaitlim no %s līdz %s.',
	'General_YourChangesHaveBeenSaved' => 'Izmaiņas saglabātas.',
	'General_ErrorRequest' => 'Diemžēl&hellip notika problēma pieprasījuma laikā, lūdzu mēģiniet vēlreiz.',
	'General_ColumnNbUniqVisitors' => 'Unikālie apmeklētāji',
	'General_ColumnNbUniqVisitorsDocumentation' => 'Unikālo vietnes apmeklētāju skaits. Pat ja apmeklētājs apmeklē vietni vairākas reizes dienā, tas tiek pieskaitīts vienreiz.',
	'General_ColumnNbVisits' => 'Apmeklējumi',
	'General_ColumnNbVisitsDocumentation' => 'Ja apmeklētājs ierodas vietnē pirmo reizi vai arī apmeklē lapu 30 minūtes pēc pēdējā lapas skatījuma, tas tiks skaitīts kā jauns apmeklējums.',
	'General_ColumnPercentageVisits' => '% apmeklējumi',
	'General_ColumnNbActions' => 'Darbības',
	'General_ColumnNbActionsDocumentation' => 'Apmeklētāju veikto darbību skaits. Darbības ir lapu skatījumi, lejupielādes vai ārējās saites.',
	'General_NbActions' => 'Darbību skaits',
	'General_ColumnMaxActions' => 'Maksimālais darbību skaits vienā apmeklējumā',
	'General_ColumnSumVisitLength' => 'Kopā apmeklētāju pavadītais laiks (sekundēs)',
	'General_ColumnLabel' => 'Etiķete',
	'General_ColumnConversionRate' => 'Konversijas likme',
	'General_ColumnConversionRateDocumentation' => 'To apmeklējumu daļa, kuri sasnieguši kādu no mērķiem.',
	'General_ColumnActionsPerVisit' => 'Darbības vienā apmeklējumā',
	'General_ColumnActionsPerVisitDocumentation' => 'Vidējais darbību (lapas skatījumu, lejupielāžu un ārējo saišu) skaits, kas tika veiktas apmeklējuma laikā.',
	'General_VisitDuration' => 'Vid. apmeklējuma garums (sekundēs)',
	'General_ColumnAvgTimeOnSite' => 'Vid. laiks vietnē',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Vidējais apmeklējuma laiks',
	'General_ColumnVisitDuration' => 'Apmeklējuma ilgums (sekundēs)',
	'General_ColumnBounceRate' => 'Atlēcienu biežums',
	'General_ColumnBounceRateDocumentation' => 'Apmeklējumu daļa, kuru laikā bija tikai viens lapas skatījums. Tas nozīmē, ka apmeklētājs pameta vietni uzreiz pēc ierašanās tajā.',
	'General_ColumnBounceRateForPageDocumentation' => 'Apmeklējumu daļa, kas sākās un beidzās šajā lapā.',
	'General_ColumnPageBounceRateDocumentation' => 'Apmeklējumu daļa, kas sākās un uzreiz beidzās šajā lapā.',
	'General_ColumnExitRate' => 'Izejas biežums',
	'General_ColumnExitRateDocumentation' => 'Apmeklējumu daļa, kas beidzās pēc šīs lapas apskates.',
	'General_ColumnPageviews' => 'Lapu skatījumi',
	'General_ColumnPageviewsDocumentation' => 'Lapu skatījumu skaits.',
	'General_ColumnUniquePageviews' => 'Unikāli lapu skatījumi',
	'General_ColumnUniquePageviewsDocumentation' => 'Apmeklējumu, kuri iekļauj šo lapu, skaits. Ja lapa tika apskatīta vairākas reizes, tā tika pieskaitīta vienreiz.',
	'General_ColumnBounces' => 'Atlēcieni',
	'General_ColumnBouncesDocumentation' => 'To apmeklējumu skaits, kuri sākās un beidzās šajā lapā. T.i. apmeklētājs, apskatījis tikai šo lapu, pameta vietni.',
	'General_ColumnUniqueEntrances' => 'Unikālas ieejas',
	'General_ColumnEntrances' => 'Ieejas',
	'General_ColumnEntrancesDocumentation' => 'To apmeklējumu skaits, kas sākās šajā lapā',
	'General_ColumnExits' => 'Izejas',
	'General_ColumnUniqueExits' => 'Unikālas izejas',
	'General_ColumnExitsDocumentation' => 'To apmeklējumu skaits, kas beidzās šajā lapā',
	'General_ColumnAverageTimeOnPage' => 'Vid. laiks lapā',
	'General_ColumnAverageTimeOnPageDocumentation' => 'Vidējais šīs lapas apmeklējuma garums (tikai šīs lapas, ne visas vietnes).',
	'General_ColumnValuePerVisit' => 'Ienākumi uz vienu apmeklējumu',
	'General_ColumnVisitsWithConversions' => 'Apmeklējumi ar reklāmguvumiem',
	'General_VisitsWith' => 'Apmeklējumi ar %s',
	'General_YearsDays' => '%1$s gadi, %2$s dienas',
	'General_HoursMinutes' => '%1$s stundas, %2$s min.',
	'General_MinutesSeconds' => '%1$s min., %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Saglabāt',
	'General_Faq' => 'BUJ',
	'General_ForExampleShort' => 'piemēram,',
	'General_YouMustBeLoggedIn' => 'Lai tiktu pie šīs funkcionalitātes, Jums jāpiesakās.',
	'General_Website' => 'Vietne',
	'General_GeneralSettings' => 'Vispārīgie iestatījumi',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Atļaut aktivizēt Piwik arhivēšanu, kad atskaites tiek apskatīta izmantojot pārlūkprogrammu',
	'General_ArchivingInlineHelp' => 'Vidēja un augsta apmeklējuma vietnēm rekomendējam atslēgt pārlūka izsauktu Piwik arhivēšanu. Tā vietā iesakam lietot cron darbu, kas arhivē Piwik katru stundu.',
	'General_ArchivingTriggerDescription' => 'Apjomīgām Piwik instalācijām iesakam %siestatīt cron darbu%s, kas apstrādās atskaites automātiski.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Lai iegūtu vairāk informāciju, apskatiet %soficiālo dokumentāciju%s.',
	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Šodienas atskaites (vai jebkura laika posma, tai skaitā šodienas) tiks apstrādātas ne biežāk kā',
	'General_NSeconds' => '%s sekundes',
	'General_SmallTrafficYouCanLeaveDefault' => 'Maza apmeklējuma vietnēm Jūs varat atstāt pēc noklusējuma iestatītās %s sekundes un visas atskates būs pieejamas reāllaikā.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Vidēja un augsta apmklējuma vietnēm iesakam apstrādāt atskaites ne biežāk kā katru pusstundu (%s sekundes) vai katru stundu (%s sekundes).',
	'General_RequiresFlash' => 'Lai Piwik parādītu grafikus ir nepieciešams Flash',
	'General_GraphHelp' => 'Vairāk informācijas par grafiku parādīšanu Piwik',
	'General_NoDataForGraph' => 'Nav datu šim grafikam.',
	'General_NoDataForTagCloud' => 'Nav datu šim iezīmju mākonim.',
	'General_DisplaySimpleTable' => 'Rādīt vienkāršu tabulu',
	'General_DisplayTableWithMoreMetrics' => 'Rādīt tabulu ar vairāk datiem',
	'General_DisplayTableWithGoalMetrics' => 'Rādīt tabulu ar mērķu datiem',
	'General_YouAreViewingDemoShortMessage' => 'Jūs pašlaik skatāties Piwik demonstrāciju',
	'General_DownloadFullVersion' => '%1$sLejupielādējiet%2$s pilno versiju! Paskaties %3$s',
	'General_NewUpdatePiwikX' => 'Jauns atjauninājums: Piwik %s',
	'General_AboutPiwikX' => 'Par Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Ir pieejams Piwik %1$s. %2$sLūdzu atjauniniet tagad!%3$s (apskatiet %4$sizmaiņas%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s ir pieejams. Lūdzu paziņojiet vietnes administratoram.',
	'General_NewReportsWillBeProcessedByCron' => 'Kad Piwik arhivēšanu neizsauc pārlūkprogramma, jaunas atskaites tiek apstrādātas izmantojot cron darbus.',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Tāpēc atskaites tiks apstrādātas ne biežāk kā vienreiz stundā.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Pieņemot, ka arhivēšana Jūsu gadījumā būs ātra, Jūs varat iestatīt starp cron darbiem mazāku intervālu.',
	'General_BackToPiwik' => 'Atpakaļ uz Piwik',
	'General_ClickHere' => 'Lai saņemtu papildus informāciju, klikšķiniet šeit.',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Jūn',
	'General_ShortMonth_7' => 'Jūl',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Janvāris',
	'General_LongMonth_2' => 'Februāris',
	'General_LongMonth_3' => 'Marts',
	'General_LongMonth_4' => 'Aprīlis',
	'General_LongMonth_5' => 'Maijs',
	'General_LongMonth_6' => 'Jūnijs',
	'General_LongMonth_7' => 'Jūlijs',
	'General_LongMonth_8' => 'Augusts',
	'General_LongMonth_9' => 'Septembris',
	'General_LongMonth_10' => 'Oktobris',
	'General_LongMonth_11' => 'Novembris',
	'General_LongMonth_12' => 'Decembris',
	'General_ShortDay_1' => 'P',
	'General_ShortDay_2' => 'O',
	'General_ShortDay_3' => 'T',
	'General_ShortDay_4' => 'C',
	'General_ShortDay_5' => 'Pk',
	'General_ShortDay_6' => 'S',
	'General_ShortDay_7' => 'Sv',
	'General_LongDay_1' => 'Pirmdiena',
	'General_LongDay_2' => 'Otrdiena',
	'General_LongDay_3' => 'Trešdiena',
	'General_LongDay_4' => 'Ceturtdiena',
	'General_LongDay_5' => 'Piektdiena',
	'General_LongDay_6' => 'Sestdiena',
	'General_LongDay_7' => 'Svētdiena',
	'General_Daily' => 'Katru dienu',
	'General_Weekly' => 'Katru nedēļu',
	'General_Monthly' => 'Katru mēnesi',
	'General_ConfigFileIsNotWritable' => 'Piwik iestatījumu datne %s nav rakstāma, dažas no izmaiņām iespējams netiks saglabātas. %s Lūdzu izmainiet iestatījumu datnes atļaujas, lai tajā varētu ierakstīt.',
	'General_ExceptionDatabaseVersion' => 'Jūsu %1$s versija ir %2$s, bet Piwik nepieciešams vismaz %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Jūsu %1$s klienta versija ir %2$s, kas nav saderīga ar servera %3$s versiju.',
	'General_ExceptionMissingFile' => 'Fails: %s neeksistē',
	'General_ExceptionFilesizeMismatch' => 'Faila izmērs nesakrīt: %1$s (sagaidāmais izmērs: %2$s, atrasts: %3$s)',
	'General_ExceptionFileIntegrity' => 'Integritātes pārbaude izgāzās: %s',
	'General_PleaseSpecifyValue' => 'Lūdzu norādiet \'%s\' vērtību.',
	'General_ExceptionGoalNotFound' => 'Mērķis ar id = %s netika atrasts.',
	'General_ExceptionUndeletableFile' => 'Nevar izdzēst %s',
	'General_ExceptionPrivilege' => 'Lai apskatītu šo sadaļu, Jums ir nepieciešama %s pieeja.',
	'General_ExceptionConfigurationFileNotFound' => 'Iestatījumu datne {%s} netika atrasta.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Iestatījumu datni {%s} nav iespējams nolasīt. Jūsu resursdatorā iespējams ir izslēgts %s.',
	'General_ExceptionInvalidToken' => 'Kods nav pareizs.',
	'General_ExceptionLanguageFileNotFound' => '\'%s\' valodas datne netika atrasta.',
	'General_ExceptionUnableToStartSession' => 'Nav iespējams sākt sesiju.',
	'General_WarningFileIntegritySkipped' => 'Detektēta izstrādes vide. Datņu integritātes pārbaude netiks veikta.',
	'General_WarningFileIntegrityNoManifest' => 'Datņu integritātes pārbaudi nav iespējams veikt, jo trūkst manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Datņu integritātes pārbaudi nav iespējams pabeigt, jo trūkst md5_file() metodes.',
	'General_UseSMTPServerForEmail' => 'Lietot SMTP serveri e-pastam',
	'General_SmtpServerAddress' => 'SMTP servera adrese',
	'General_SmtpPort' => 'SMTP ports',
	'General_AuthenticationMethodSmtp' => 'SMTP autentifikācijas metode',
	'General_SmtpUsername' => 'SMTP lietotājvārds',
	'General_SmtpPassword' => 'SMTP parole',
	'General_SmtpEncryption' => 'SMTP kriptēšana',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Ja vēlies vai ir nepieciešans sūtīt e-pastus caur serveri neizmantojot lokālo "mail" metodi, izvēlies "Jā"',
	'General_OptionalSmtpPort' => 'Izvēles. Pēc noklusējuma 25 nekriptētētam un TLS SMTP, bet 465 izmantojot SSL SMTP.',
	'General_OnlyEnterIfRequired' => 'Ievadiet lietotājvārdu tikai tad, ja Jūsu SMTP serveris to pieprasa.',
	'General_OnlyEnterIfRequiredPassword' => 'Ievadiet paroli tikai tad, ja Jūsu SMTP serveris to pieprasa.',
	'General_InvalidResponse' => 'Saņemtie dati nav pareizi.',
	'General_ChooseLanguage' => 'Izvēlieties valodu',
	'General_ChoosePeriod' => 'Izvēlieties periodu',
	'General_ChooseWebsite' => 'Izvēlieties lapu',
	'General_Language' => 'Valoda',
	'General_PleaseUpdatePiwik' => 'Lūdzu modernizējiet savu Piwik',
	'General_RequestTimedOut' => '%s datu pieprasījumam iestājās noilgums. Lūdzu mēģiniet vēlreiz.',
	'General_UsePlusMinusIconsDocumentation' => 'Lai pārvietotos, lietojiet pa kreisi esošās plusa un mīnusa ikonas.',
	'General_Recommended' => '(ieteicams)',
	'General_Goal' => 'Mērķis',
	'General_Outlink' => 'Ārēja saite',
	'General_Help' => 'Palīdzība',
	'General_DailySum' => 'dienas summa',
	'General_AfterEntry' => 'pēc nonākšanas šeit',
	'General_Metadata' => 'Metadati',
	'General_OneVisit' => '1 apmeklējums',
	'General_NVisits' => '%s apmeklējumi',
	'General_OneDay' => '1 diena',
	'General_NDays' => '%s dienas',
	'General_MainMetrics' => 'Galvenie mērījumi',
	'Actions_PluginDescription' => 'Lapas skatījumu, izejošo saišu un lejupielāžu atskaite. Izejošo saišu un lejupielāžu izsekošana ir automātiska!',
	'Actions_Actions' => 'Darbības',
	'Actions_SubmenuPages' => 'Lapas',
	'Actions_SubmenuPagesEntry' => 'Ieejas lapas',
	'Actions_SubmenuPagesExit' => 'Izejas lapas',
	'Actions_SubmenuPageTitles' => 'Lapas virsraksti',
	'Actions_SubmenuOutlinks' => 'Ārējās saites',
	'Actions_SubmenuDownloads' => 'Lejupielādes',
	'Actions_ColumnClicks' => 'Klikšķi',
	'Actions_ColumnClicksDocumentation' => 'Saites klikšķu skaits.',
	'Actions_ColumnUniqueClicks' => 'Unikālie klikšķi',
	'Actions_ColumnDownloads' => 'Lejupielādes',
	'Actions_ColumnUniqueDownloads' => 'Unikālas lejupielādes',
	'Actions_ColumnOutlinks' => 'Ārējās saites',
	'Actions_ColumnUniqueOutlinks' => 'Unikālās arējās saites',
	'Actions_ColumnPageName' => 'Lapas virsraksts',
	'Actions_ColumnPageURL' => 'Lapas URL',
	'Actions_ColumnClickedURL' => 'Klikšķinātais URL',
	'Actions_ColumnDownloadURL' => 'Lejupielādes URL',
	'Actions_ColumnEntryPageURL' => 'Ieejas lapas URL',
	'Actions_ColumnEntryPageTitle' => 'Ieejas lapas virsraksts',
	'Actions_ColumnExitPageURL' => 'Izejas lapas URL',
	'Actions_ColumnExitPageTitle' => 'Izejas lapas virsraksts',
	'AnonymizeIP_PluginDescription' => 'Anonimizē apmeklētāju IP adrešu pēdējo baitu(s). Nepieciešamību nosaka Jūsu vietējie privātuma likumi/pavadlīnijas.',
	'API_PluginDescription' => 'Visi Piwik dati ir pieejami caur vienkāršiem API. Šis spraudnis ir tīkla servisa pieejas punkts, kuru varat izsaukt, lai iegūtu savus tīkla analīzes datus xml, json, php, csv un citos formātos.',
	'API_QuickDocumentationTitle' => 'Ātra API dokumentācija',
	'API_UserAuthentication' => 'Lietotāja autentifikācija',
	'CoreAdminHome_PluginDescription' => 'Piwik administrācijas sadaļa.',
	'CoreAdminHome_MenuGeneralSettings' => 'Vispārīgie iestatījumi',
	'CoreAdminHome_Administration' => 'Administrācija',
	'CoreAdminHome_EmailServerSettings' => 'E-pasta servera iestatījumi',
	'CoreAdminHome_YouAreOptedIn' => 'Jūs pašlaik esiet izvēlējušies piedalīties.',
	'CoreAdminHome_YouAreOptedOut' => 'Jūs pašlaik esiet izvēlējušies nepiedalīties.',
	'CoreAdminHome_ClickHereToOptOut' => 'Lai nepiedalītos, klikšķiniet šeit.',
	'CoreAdminHome_ClickHereToOptIn' => 'Lai piedalītos, klikšķiniet šeit.',
	'CoreAdminHome_BrandingSettings' => 'Zīmola iestatījumi',
	'CoreAdminHome_UseCustomLogo' => 'Lietot izvēles logo',
	'CoreAdminHome_LogoUpload' => 'Izvēlēties logo augšuplādei',
	'PrivacyManager_TeaserHeadline' => 'Privātuma iestatījumi',
	'PrivacyManager_MenuPrivacySettings' => 'Privātums',
	'PrivacyManager_UseAnonymizeIp' => 'Anonimizēt apmeklētāju IP adreses',
	'PrivacyManager_DeleteLogInfo' => 'Tiks dzēsti žurnāli no sekojošām tabulām: %s',
	'PrivacyManager_UseDeleteLog' => 'Regulāri dzēst no datubāzes vecus apmeklētāju žurnālus',
	'PrivacyManager_DeleteLogsOlderThan' => 'Dzēst vecākus žurnālus par',
	'PrivacyManager_DeleteMaxRows' => 'Maksimālais rindu skaits ko dzēst vienā reizē:',
	'PrivacyManager_LastDelete' => 'Pēdējā dzēšana notika',
	'PrivacyManager_NextDelete' => 'Nākošā dzēšana paredzēta',
	'PrivacyManager_ClickHereSettings' => 'Klikšķiniet šeit lai piekļūtu %s iestatījumiem.',
	'PrivacyManager_LeastDaysInput' => 'Lūdzu izvēlieties dienu skaitu lielāku par %s.',
	'CoreHome_PluginDescription' => 'Tīkla analīzes atskaišu struktūra',
	'CoreHome_WebAnalyticsReports' => 'Tīkla analīzes atskaites',
	'CoreHome_NoPrivilegesAskPiwikAdmin' => 'Jūs esat ienākuši kā \'%s\', bet izskatās, ka Jums nav iestatītas vajadzīgās Piwik atļaujas. %s Pieprasiet savam Piwik administratoram (klikšķiniet, lai nosūtītu e-pastu)%s Jums pieslēgt vietnes apskates atļauju.',
	'CoreHome_JavascriptDisabled' => 'Lai lietotu Piwik tā standartskatā, ir jāieslēdz JavaScript.<br />Tomēr izskatās, ka JavaScript atbalsts ir izslēgts vai arī to neatbalsts Jūsu pārlūks.<br />Lai lietotu standartskatu, ieslēdziet JavaScript atbalstu pārlūka iestatījumos, tad %1$smēģiniet atkārtoti%2$s.<br />',
	'CoreHome_ThereIsNoDataForThisReport' => 'Nav šajai atskaitei vajadzīgo datu.',
	'CoreHome_CategoryNoData' => 'Nav datu šajā kategorijā. Mēģiniet izvēlēties "Iekļaut visu apmeklējumu".',
	'CoreHome_ShowJSCode' => 'Rādīt ievietošanai paredzēto JavaScript kodu',
	'CoreHome_PageOf_js' => '%1$s no %2$s',
	'CoreHome_PeriodDay' => 'Diena',
	'CoreHome_PeriodWeek' => 'Nedēļa',
	'CoreHome_PeriodMonth' => 'Mēnesis',
	'CoreHome_PeriodYear' => 'Gads',
	'CoreHome_PeriodDays' => 'dienas',
	'CoreHome_PeriodWeeks' => 'nedēļas',
	'CoreHome_PeriodMonths' => 'mēneši',
	'CoreHome_PeriodYears' => 'gadi',
	'CoreHome_DaySu_js' => 'Sv',
	'CoreHome_DayMo_js' => 'P',
	'CoreHome_DayTu_js' => 'O',
	'CoreHome_DayWe_js' => 'T',
	'CoreHome_DayTh_js' => 'C',
	'CoreHome_DayFr_js' => 'Pk',
	'CoreHome_DaySa_js' => 'S',
	'CoreHome_ShortDay_1_js' => 'Sv',
	'CoreHome_ShortDay_2_js' => 'P',
	'CoreHome_ShortDay_3_js' => 'O',
	'CoreHome_ShortDay_4_js' => 'T',
	'CoreHome_ShortDay_5_js' => 'C',
	'CoreHome_ShortDay_6_js' => 'Pk',
	'CoreHome_ShortDay_7_js' => 'S',
	'CoreHome_LongDay_1_js' => 'Svētdiena',
	'CoreHome_LongDay_2_js' => 'Pirmdiena',
	'CoreHome_LongDay_3_js' => 'Otrdiena',
	'CoreHome_LongDay_4_js' => 'Trešdiena',
	'CoreHome_LongDay_5_js' => 'Ceturtdiena',
	'CoreHome_LongDay_6_js' => 'Piektdiena',
	'CoreHome_LongDay_7_js' => 'Sestdiena',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Mai',
	'CoreHome_ShortMonth_6_js' => 'Jūn',
	'CoreHome_ShortMonth_7_js' => 'Jūl',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'Janvāris',
	'CoreHome_MonthFebruary_js' => 'Februāris',
	'CoreHome_MonthMarch_js' => 'Marts',
	'CoreHome_MonthApril_js' => 'Aprīlis',
	'CoreHome_MonthMay_js' => 'Maijs',
	'CoreHome_MonthJune_js' => 'Jūnijs',
	'CoreHome_MonthJuly_js' => 'Jūlijs',
	'CoreHome_MonthAugust_js' => 'Augusts',
	'CoreHome_MonthSeptember_js' => 'Septembris',
	'CoreHome_MonthOctober_js' => 'Oktobris',
	'CoreHome_MonthNovember_js' => 'Novembris',
	'CoreHome_MonthDecember_js' => 'Decembris',
	'CorePluginsAdmin_PluginDescription' => 'Spraudņu administrācijas skats',
	'CorePluginsAdmin_Plugins' => 'Spraudņi',
	'CorePluginsAdmin_PluginsManagement' => 'Spraudņu pārvaldība',
	'CorePluginsAdmin_MainDescription' => 'Spraudņi paplašina Piwik funkcionalitāti. Pēc spraudņa instalācijas, Jūs to varat aktivizēt (vai deaktivizēt) šeit.',
	'CorePluginsAdmin_Plugin' => 'Spraudnis',
	'CorePluginsAdmin_Version' => 'Versija',
	'CorePluginsAdmin_Status' => 'Statuss',
	'CorePluginsAdmin_Action' => 'Darbība',
	'CorePluginsAdmin_AuthorHomepage' => 'Autora vietne',
	'CorePluginsAdmin_LicenseHomepage' => 'Licences vietne',
	'CorePluginsAdmin_PluginHomepage' => 'Spraudņa vietne',
	'CorePluginsAdmin_Activated' => 'Aktivizēts',
	'CorePluginsAdmin_Active' => 'Aktīvs',
	'CorePluginsAdmin_Inactive' => 'Neaktīvs',
	'CorePluginsAdmin_Deactivate' => 'Deaktivizēt',
	'CorePluginsAdmin_Activate' => 'Aktivizēt',
	'CorePluginsAdmin_MenuPlugins' => 'Spraudņi',
	'CoreUpdater_PluginDescription' => 'Piwik atjaunināšanas mehānisms',
	'CoreUpdater_UpdateTitle' => 'Atjaunināt',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Vajadzīgs datubāzes atjauninājums',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Jūsu Piwik datubāze ir novecojusi un tā ir jaatjaunina pirms varēsiet turpināt',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik datubāze tiks atjaunināta no %1$s līdz %2$s versijai.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Sekojošie spraudņi tiks atjaunināti: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Svarīgas piezīmes lielām Piwik instalācijām',
	'CoreUpdater_ReadyToGo' => 'Esat gatavi?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Datubāzes atjaunināšana var aizņemt kādu laiku, esiet pacietīgi.',
	'CoreUpdater_UpgradePiwik' => 'Atjaunināt Piwik',
	'CoreUpdater_UpgradeComplete' => 'Atjaunināšana pabeigta!',
	'CoreUpdater_WarningMessages' => 'Brīdinājumi:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Kļūda atjaunojot spraudņus:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Mēs automātiski deaktivizējām sekojošus spraudņus: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik tika veiksmīgi atjaunināts',
	'CoreUpdater_ContinueToPiwik' => 'Turpināt uz Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Atjaunināt automātiski',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Ir pieejama atjaunināšanai jauna Piwik versija',
	'CoreUpdater_DownloadX' => 'Lejupielādē %s',
	'CoreUpdater_DownloadingUpdateFromX' => 'Notiek atjauninājuma ielāde no %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Notiek atjauninājuma atpakošana',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Notiek atpakoto datņu pārbaude',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Tiek veikta iestatījumu datnes rezerver kopēšana kā %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Tiek instalēta jaunākā versija',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik atjaunināts veiksmīgi!',
	'CoreUpdater_EmptyDatabaseError' => 'Datubāze %s ir tukša. Jums jāizlabo vai jāizdzēš Jūsu Piwik iestatījumu datne.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Jūsu Piwik versija %s ir jaunākā pieejamā.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nesaderīgs arhīvs: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Tukšs arhīvs',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arhīvs nav pilnīgs: trūkst dažas datnes (piem., %s).',
	'Dashboard_PluginDescription' => 'Jūsu tīkla analīzes panelis. Jūs varat pielāgot savu paneli pievienojot logdaļas vai mainot to izkārtojumu. Katram lietotājam var būt savs, pielāgots panelis.',
	'Dashboard_Dashboard' => 'Panelis',
	'Dashboard_DeleteWidgetConfirm' => 'Vai tiešām vēlaties dzēst šo logdaļu no paneļa?',
	'Dashboard_SelectWidget' => 'Izvēlieties to logdaļu, kuru vēlaties pievienot panelim',
	'Dashboard_AddPreviewedWidget_js' => 'Pievienot apskatīto logdaļu panelim',
	'Dashboard_WidgetPreview_js' => 'Logdaļas priekšstatījums',
	'Dashboard_Close_js' => 'Aizvērt',
	'Dashboard_Maximise_js' => 'Izvērst',
	'Dashboard_Minimise_js' => 'Samazināt',
	'Dashboard_TitleWidgetInDashboard_js' => 'Logdaļa jau atrodas panelī',
	'Dashboard_TitleClickToAdd_js' => 'Klikšķiniet, lai pievienotu panelim',
	'Dashboard_LoadingWidget_js' => 'Notiek logdaļas ielāde, lūdzu uzgaidiet...',
	'Dashboard_WidgetNotFound_js' => 'Logdaļa nav atrasta',
	'DBStats_PluginDescription' => 'Šis spraudnis sniedz MySQL datubāzes Piwik tabulu lietojuma atskaites.',
	'DBStats_DatabaseUsage' => 'Datubāzes lietojums',
	'DBStats_MainDescription' => 'Piwik glabā visus Jūsu tīkla analīzes datus MySQL datubāzē. Pašlaik Piwik tabulas lieto %s.',
	'DBStats_LearnMore' => 'Lai uzzinātu vairāk par to, kā Piwik apstrādā datus un kā Piwik tiek galā ar vidēja un augsta apmeklējuma vietnēm, apskatiet dokumentāciju %s.',
	'DBStats_Table' => 'Tabula',
	'DBStats_RowCount' => 'Rindu skaits',
	'DBStats_DataSize' => 'Datu izmērs',
	'DBStats_IndexSize' => 'Indeksa izmērs',
	'DBStats_TotalSize' => 'Kopējais izmērs',
	'Feedback_PluginDescription' => 'Sūtiet savas atsauksmes Piwik komandai. Dalieties ar savām idejām un ieteikumiem ar mums!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Vai Jums ir kļūdas ziņojums vai papildus funkcionalitātes pieprasījums?',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Kāpēc netiek uzskaitīts manas vietnes apmeklējums?',
	'Feedback_HowToExclude' => 'Kā izslēgt manu apmeklējumu uzskaiti?',
	'Feedback_WhyWrongCountry' => 'Kāpēc Piwik rāda manu apmeklējumu no nepareizas valsts?',
	'Feedback_HowToAnonymizeIP' => 'Kā lai nomaskēju apmeklētāju IP adreses?',
	'Feedback_LearnWaysToParticipate' => 'Uzzināt vairāk par to, kā Jūs varat %s piedalīties%s',
	'Feedback_SpecialRequest' => 'Vai Jums ir speciāls pieprasījums Piwik komandai?',
	'Feedback_ContactThePiwikTeam' => 'Kontaktēties ar Piwik komandu!',
	'Feedback_IWantTo' => 'Es vēlos:',
	'Feedback_CategoryShareStory' => 'Dalīties ar Piwik veiksmes stāstu',
	'Feedback_CategorySponsor' => 'Sponsorēt Piwik',
	'Feedback_CategoryHire' => 'Nolīgt Piwik konsultantu',
	'Feedback_CategorySecurity' => 'Ziņot par drošības problēmu',
	'Feedback_MyEmailAddress' => 'Mana e-pasta adrese:',
	'Feedback_MyMessage' => 'Mans ziņa:',
	'Feedback_DetailsPlease' => '(lūdzu norādiet detaļas)',
	'Feedback_SendFeedback' => 'Sūtīt atsauksmes',
	'Feedback_ManuallySendEmailTo' => 'Lūdzu manuāli nosūtiet savu ziņu uz',
	'Feedback_MessageSent' => 'Jūsu ziņa tika nosūtīta Piwik komandai.',
	'Feedback_ThankYou' => 'Paldies, ka palīdzat uzlabot Piwik!',
	'Feedback_ThePiwikTeam' => 'Piwik komanda',
	'Feedback_ExceptionBodyLength' => 'Ziņai ir jābūt vismaz %s simbolus garai.',
	'Feedback_ExceptionNoUrls' => 'Lai izvairītos no mēstulēm, ziņa nedrīkst saturēt saites.',
	'Goals_Goals' => 'Mērķi',
	'Goals_EcommerceAndGoalsMenu' => 'E-komercija un mērķi',
	'Goals_Ecommerce' => 'E-komercija',
	'Goals_EcommerceOverview' => 'E-komercijas pārskats',
	'Goals_EcommerceOrder' => 'E-komercijas pasūtījums',
	'Goals_EcommerceLog' => 'E-komercijas žurnāls',
	'Goals_AbandonedCart' => 'Pamestie iepirkumu grozi',
	'Goals_LeftInCart' => '%s atstāti grozā',
	'Goals_GoalsOverview' => 'Mērķu pārskats',
	'Goals_GoalsManagement' => 'Mērķu pārvaldība',
	'Goals_EcommerceReports' => 'E-komercijas atskaites',
	'Goals_ViewGoalsBy' => 'Skatīt mērķus pēc %s',
	'Goals_ColumnRevenue' => 'Ienākumi',
	'Goals_DocumentationRevenueGeneratedByProductSales' => 'Pārdotie produkti. Neskaitot nodokļus, piegādi un atlaidi.',
	'Goals_ColumnRevenueDocumentation' => 'Kopējie ienākumi, kurus veido %s.',
	'Goals_ColumnAveragePriceDocumentation' => 'Vidējie ienākumi %s.',
	'Goals_ColumnAverageQuantityDocumentation' => '%s vidējais pārdotais skaits e-komercijas pasūtījumos.',
	'Goals_GoalX' => 'Mērķis %s',
	'Goals_AddNewGoal' => 'Pievienot jaunu mērķi',
	'Goals_AddGoal_js' => 'Pievienot mērķi',
	'Goals_UpdateGoal_js' => 'Atjaunināt mērķi',
	'Goals_DeleteGoalConfirm_js' => 'Vai tiešām vēlaties dzēst mērķi %s?',
	'Goals_CreateNewGOal' => 'Izveidot jaunu mērķi',
	'Goals_ViewAndEditGoals' => 'Skatīt un labot mērķus',
	'Goals_GoalName' => 'Mērķa nosaukums',
	'Goals_GoalIsTriggered' => 'Mērķis tiek sasniegts',
	'Goals_GoalIsTriggeredWhen' => 'Mērķis tiek sasniegts, kad',
	'Goals_WhenVisitors' => 'kad apmeklētāji',
	'Goals_WhereThe' => ', kur',
	'Goals_Manually' => 'manuāli',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Mērķis tiem manuāli sasniegts izmantojot JavaScript API trackGoal() metodi',
	'Goals_URL' => 'URL',
	'Goals_PageTitle' => 'Lapas virsraksts',
	'Goals_Filename' => 'datnes nosaukums',
	'Goals_ExternalWebsiteUrl' => 'ārējās vietnes URL',
	'Goals_Download' => 'Lejupielādēt datni',
	'Goals_VisitPageTitle' => 'Apmeklēt doto lapas virsrakstu',
	'Goals_ClickOutlink' => 'Klikšķis uz ārējas vietnes saites',
	'Goals_Optional' => '(izvēles)',
	'Goals_DefaultRevenue' => 'Mērķa peļņa pēc noklusējuma ir',
	'Goals_Contains' => 'satur %s',
	'Goals_IsExactly' => 'ir precīzi %s',
	'Goals_MatchesExpression' => 'sakrīt ar %s',
	'Goals_CaseSensitive' => 'Reģistrjūtīga saderība',
	'Goals_Pattern' => 'Modelis',
	'Goals_ProductSKU' => 'Produkta kods',
	'Goals_ProductName' => 'Produkta nosaukums',
	'Goals_ProductCategory' => 'Produkta kategorija',
	'Goals_Products' => 'Produkti',
	'Installation_Installation' => 'Instalācija',
	'Installation_InstallationStatus' => 'Instalācijas statuss',
	'Installation_PercentDone' => '%s %% pabeigts',
	'Installation_DatabaseSetup' => 'Datubāzes iestatīšana',
	'Installation_DatabaseSetupServer' => 'datubāzes serveris',
	'Installation_DatabaseSetupLogin' => 'lietotājvārds',
	'Installation_DatabaseSetupPassword' => 'parole',
	'Installation_DatabaseSetupDatabaseName' => 'datubāzes nosaukums',
	'Installation_DatabaseSetupTablePrefix' => 'tabulas prefikss',
	'Installation_DatabaseSetupAdapter' => 'adapteris',
	'Installation_DatabaseErrorConnect' => 'Kļūda mēģinot sasniegt datubāzes serveri',
	'Installation_DatabaseCheck' => 'Datubāzes pārbaude',
	'Installation_DatabaseServerVersion' => 'Datubāzes servera versija',
	'Installation_DatabaseClientVersion' => 'Datubāzes klienta versija',
	'Installation_DatabaseCreation' => 'Datubāzes izveide',
	'Installation_PleaseFixTheFollowingErrors' => 'Lūdzu izlabojiet sekojošās kļūdas',
	'Installation_LargePiwikInstances' => 'Palīdzība ar lielām Piwik instancēm',
	'Installation_JsTag' => 'JavaScript izsekošanas kods',
	'Installation_Congratulations' => 'Apsveicam',
	'Installation_ContinueToPiwik' => 'Turpināt uz Piwik',
	'Installation_SetupWebsite' => 'Iestatiet vietni',
	'Installation_SetupWebSiteName' => 'vietnes nosaukums',
	'Installation_SetupWebSiteURL' => 'vietnes URL',
	'Installation_Timezone' => 'vietnes laika zona',
	'Installation_SetupWebsiteError' => 'Vietnes pievienošana izraisīja kļūdu',
	'Installation_SetupWebsiteSetupSuccess' => 'Vietne %s ir veiksmīgi izveidota!',
	'Installation_SuperUser' => 'Superlietotājs',
	'Installation_SuperUserSetupSuccess' => 'Superlietotājs tika veiksmīgi izveidots!',
	'Installation_SuperUserLogin' => 'Superlietotāja lietotājvārds',
	'Installation_Password' => 'parole',
	'Installation_PasswordRepeat' => 'parole (atkārtoti)',
	'Installation_Email' => 'e-pasta adrese',
	'Installation_SecurityNewsletter' => 'sūtiet e-pastu par svarīgiem Piwik atjauninājumiem un drošības paziņojumiem',
	'Installation_CommunityNewsletter' => 'sūtiet epastu par kopienas jaunumiem (jauniem spraudņiem, jaunām iespējām, utt.)',
	'Installation_PasswordDoNotMatch' => 'paroles nesakrīt',
	'Installation_Requirements' => 'Piwik prasības',
	'Installation_Optional' => 'Izvēles',
	'Installation_Legend' => 'Leģenda',
	'Installation_Extension' => 'paplašinājums',
	'Installation_SystemCheck' => 'Sistēmas pārbaude',
	'Installation_SystemCheckPhp' => 'PHP versija',
	'Installation_SystemCheckExtensions' => 'Citi vajadzīgie paplašinājumi',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik vajag vai nu mysqli paplašinājumu vai gan PDO un pdo_mysql paplašinājumus.',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Uz Linux servera Jūs varat kompilēt php ar sekojošiem parametriem: %1$s Savā php.ini datnē pievienojiet sekojošas līnijas: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Vairāk informācija par <a style="color:red" href="http://php.net/pdo">PHP PDO</a> un <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Uz Windows servera Jūs varat pievienot sekojošas līnijas savā php.ini datnē: %s',
	'Installation_SystemCheckSplHelp' => 'Jums jāiestata un jāpārbūvē PHP ar ieslēgtu Standard PHP Library (SPL) (pēc noklusējuma).',
	'Installation_SystemCheckZlibHelp' => 'Jums jāiestata un jāpārbūvē PHP ar ieslēgtu "zlib" atbalstu, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Jums jāiestata un jāpārbūvē PHP ar ieslēgtu "iconv" atbalstu, --with-iconv.',
	'Installation_SystemCheckOtherExtensions' => 'Citi paplašinājumi',
	'Installation_SystemCheckWarnLibXmlHelp' => 'Jums ir jāieslēdz "libxml" paplašinājums (piem., instalējiet "php-libxml" pakotni), jo tā ir nepieciešama citiem PHP paplašinājumiem.',
	'Installation_SystemCheckWarnJsonHelp' => 'Jums ir jāieslēdz "json" paplašinājums (piem., instalējiet "php-json" pakotni) labākai veiktspējai.',
	'Installation_SystemCheckWarnDomHelp' => 'Jums ir jāieslēdz "dom" paplašinājums (piem., instalējiet "php-dom" un/vai "php-xml" pakotnes).',
	'Installation_SystemCheckWarnSimpleXMLHelp' => 'Jums ir jāieslēdz "SimpleXML" paplašinājums (piem., instalējiet "php-simplexml" un/vai "php-xml" pakotnes).',
	'Installation_SystemCheckWriteDirs' => 'Mapes ar rakstīšanas pieeju',
	'Installation_SystemCheckWriteDirsHelp' => 'Lai salabotu šo kļūdu Jūsu Linux sistēmā, pamēģiniet ierakstīt sekojošas komandas',
	'Installation_SystemCheckMemoryLimit' => 'Atmiņas limits',
	'Installation_SystemCheckOpenURL' => 'Atvērt URL',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafika)',
	'Installation_SystemCheckFunctions' => 'Nepieciešamās metodes',
	'Installation_SystemCheckOtherFunctions' => 'Citas metodes',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckFileIntegrity' => 'Datņu integritāte',
	'Installation_Tables' => 'Tiek izveidotas tabulas',
	'Installation_TablesCreatedSuccess' => 'Tabulas veiksmīgi izveidotas!',
	'Installation_DatabaseCreatedSuccess' => 'Datubāze %s veiksmīgi izveidota!',
	'Installation_GoBackAndDefinePrefix' => 'Dodieties atpakaļ un nodefinējiet Piwik tabulu prefiksu',
	'Installation_Welcome' => 'Esiet sveicināti!',
	'LanguagesManager_PluginDescription' => 'Šis spraudnis rāda visu pieejamo Piwik interfeisa valodu sarakstu. Izvēlētā valoda tiks saglabāta katra lietotāja iestatījumos.',
	'LanguagesManager_AboutPiwikTranslations' => 'Par Piwik tulkojumiem',
	'Live_PluginDescription' => 'Izspiego savus apmeklētājus, dzīvajā, reāllaikā!',
	'Live_LinkVisitorLog' => 'Apskatīt detalizētu apmeklētāju žurnālu',
	'Live_Actions' => 'Darbības',
	'Live_Action' => 'Darbība',
	'Live_VisitorsInRealTime' => 'Apmeklētāji reāllaikā',
	'Live_VisitorLog' => 'Apmeklētāju žurnāls',
	'Live_VisitorLogDocumentation' => 'Šī tabula atspoguļo pēdējos apmeklējumus izvēlētajā datumu intervālā. Jūs varat apskatīt pēdējo apmeklētāja apmeklējuma laiku kursoru uzbīdot uz apmeklējuma datuma. %s Ja datumu intervāls iekļauj šodienu, Jūs varat skatīt apmeklētājus reāllaikā! %s Dati, kas apskatāmi šeit, ir vienmēr aktuālie, neatkarīgi no tā vai lietojat arhivēšanas darbu, vai nē.',
	'Live_Time' => 'Laiks',
	'Live_Referrer_URL' => 'Atsauces URL',
	'Live_LastMinutes' => 'Pēdējās %s minūtes',
	'Live_LastHours' => 'Pēdējās %s stundas',
	'Live_GoalType' => 'Tips',
	'Live_GoalTime' => 'Pirmās konversijas laiks',
	'Live_KeywordRankedOnSearchResultForThisVisitor' => 'Atslēgvārds %1$s ir %2$s vietā %3$s šī lietotāja meklēšanas rezultātu lapā.',
	'Live_GoalRevenue' => 'Ienākumi',
	'Live_GoalDetails' => 'Detaļas',
	'Live_VisitorsLastVisit' => 'Šī apmeklētāja pēdējais apmklējums bija %s dienas atpakaļ.',
	'Login_LoginPasswordNotCorrect' => 'Lietotājvārds un parole nav korekti',
	'Login_Password' => 'Parole',
	'Login_PasswordRepeat' => 'Parole (atkārtoti)',
	'Login_ChangePassword' => 'Mainīt paroli',
	'Login_LoginOrEmail' => 'Lietotājvārds vai e-pasta adrese',
	'Login_RememberMe' => 'Atcerēties mani',
	'Login_LogIn' => 'Pieteikties',
	'Login_Logout' => 'Beigt darbu',
	'Login_LostYourPassword' => 'Pazaudēji savu paroli?',
	'Login_PasswordsDoNotMatch' => 'Paroles nesakrīt.',
	'Login_InvalidUsernameEmail' => 'Nepareizs lietotājvārds un/vai e-pasta adrese',
	'Login_InvalidNonceOrHeadersOrReferer' => 'Formas drošība nenostrādāja. Lūdzu pārlādējiet formu un pārbaudiet vai sīkfailu atbalsts ir ieslēgts. Ja lietojat starpniekserveri, Jums %s jāiestata Piwik  lai pieņemtu starpniekservera galveni %s, kas pārsūta resursdatora galveni. Papildus pārbaudiet vai Jūsu iepriekšējās vietnes galvene ir nosūtīta pareizi.',
	'Login_InvalidOrExpiredToken' => 'Kods ir nepareizs vai tam ir beidzies termiņš.',
	'Login_ContactAdmin' => 'Iespējams, ka Jūsu resursdatoram ir atslēgta mail() metode. <br />Sazinieties ar savu Piwik administrātoru.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Paroles parametram ir jābūt paroles MD5 summai.',
	'Mobile_AddAccount' => 'Pievienot kontu',
	'Mobile_AnonymousTracking' => 'Anonīma izsekošana',
	'Mobile_LastUpdated' => 'Atjaunināts: %s',
	'Mobile_PullDownToRefresh' => 'Velc lai atjauninātu...',
	'Mobile_Refresh' => 'Atjaunināt',
	'Mobile_Reloading' => 'Notiek pārlāde...',
	'Mobile_ReleaseToRefresh' => 'Atlaidiet lai atjaunotu...',
	'Mobile_ShowAll' => 'Rādīt visu',
	'Mobile_ShowLess' => 'Rādīt mazāk',
	'Mobile_HttpTimeout' => 'HTTP noilgums',
	'Mobile_VerifyAccount' => 'Notiek konta pārbaude',
	'Mobile_AnonymousAccess' => 'Anonīma pieeja',
	'Mobile_AccessUrlLabel' => 'Piwik pieejas URL',
	'Mobile_EnableGraphsLabel' => 'Rādīt grafikus',
	'Mobile_DefaultReportDate' => 'Atskaites datums',
	'Mobile_NetworkNotReachable' => 'Tīkls nav sasniedzams',
	'Mobile_NavigationBack' => 'Atpakaļ',
	'Mobile_SaveSuccessError' => 'Lūdzu pārbaudiet iestatījumus',
	'Mobile_SearchWebsite' => 'Meklēt vietnes',
	'Mobile_YouAreOffline' => 'Atvainojiet, bet Jūs paļaik atrodaties bezsaistē',
	'Provider_WidgetProviders' => 'Pakalpojumu sniedzēji',
	'Provider_ColumnProvider' => 'Pakalpojumu sniedzējs',
	'Provider_SubmenuLocationsProvider' => 'Lokācijas un pakalpojumu sniedzējs',
	'Referers_Referers' => 'Refereri',
	'Referers_SearchEngines' => 'Meklēšanas dzinēji',
	'Referers_Keywords' => 'Atslēgvārdi',
	'Referers_DirectEntry' => 'Tiešā ieeja',
	'Referers_Websites' => 'Vietnes',
	'Referers_Campaigns' => 'Kampaņas',
	'Referers_Type' => 'Referera tips',
	'Referers_ColumnRefererType' => 'Referera tips',
	'Referers_ColumnSearchEngine' => 'Meklēšanas dzinējs',
	'Referers_ColumnWebsite' => 'Vietne',
	'Referers_ColumnWebsitePage' => 'Vietnes lapa',
	'Referers_ColumnKeyword' => 'Atslēgvārds',
	'Referers_ColumnCampaign' => 'Kampaņa',
	'Referers_RefererName' => 'Referera nosaukums',
	'Referers_DetailsByRefererType' => 'Detaļas pēc referera tipa',
	'Referers_TypeDirectEntries' => '%s tiešās ieejas',
	'Referers_TypeSearchEngines' => '%s no meklēšanas dzinējiem',
	'Referers_TypeWebsites' => '%s no vietnēm',
	'Referers_TypeCampaigns' => '%s no kampaņām',
	'Referers_SubmenuOverview' => 'Pārskats',
	'Referers_SubmenuSearchEngines' => 'Meklēšanas dzinēji un atslēgvārdi',
	'Referers_SubmenuWebsites' => 'Vietnes',
	'Referers_SubmenuCampaigns' => 'Kampaņas',
	'Referers_WidgetKeywords' => 'Atslēgvārdu saraksts',
	'Referers_WidgetCampaigns' => 'Kampaņu saraksts',
	'Referers_WidgetExternalWebsites' => 'Ārējo vietņu saraksts',
	'Referers_WidgetSearchEngines' => 'Labākie meklēšanas dzinēji',
	'Referers_WidgetOverview' => 'Pārskats',
	'SecurityInfo_SecurityInformation' => 'PHP drošības informācija',
	'SecurityInfo_Test' => 'Testēt',
	'SecurityInfo_Result' => 'Rezultāts',
	'SEO_SeoRankings' => 'SEO ranks',
	'SEO_AlexaRank' => 'Alexa ranks',
	'SEO_DomainAge' => 'Domēna vecums',
	'SEO_Rank' => 'ranks',
	'SEO_Pages' => 'lapas',
	'SEO_SEORankingsFor' => '%s SEO ranks',
	'SitesManager_PluginDescription' => 'Piwik vietņu pārvaldība: pievienojiet jaunu vietni, labojiet esošās, apskatiet ievietošanai lapās paredzēto kodu. Visas darbības ir pieejamas arī izmantojot API.',
	'SitesManager_Sites' => 'Vietnes',
	'SitesManager_TrackingTags' => '%s izsekošanas kods',
	'SitesManager_WebsitesManagement' => 'Vietņu pārvaldība',
	'SitesManager_MainDescription' => 'Jūsu tīkla analīzes atskaitēm ir vajadzīgas vietnes! Pievienojiet, atjauniniet, dzēsiet vietnes un apskatiet ievietošanai lapās paredzēto kodu.',
	'SitesManager_YouCurrentlyHaveAccessToNWebsites' => 'Jums pašlaik ir pieeja %s vietnēm.',
	'SitesManager_OnlyOneSiteAtTime_js' => 'Jūs varat vienlaicīgi labot tikai vienas vietnes iestatījumus. Lūdzu saglabājiet vai atceļiet savas pašlaik veiktās izmaiņas vietnei %s.',
	'SitesManager_JsTrackingTag' => 'JavaScript izsekošanas kods',
	'SitesManager_JsTrackingTagHelp' => 'Šeit ir JavaScript izsekošanas kods, kas paredzēts ievietošanai visās Jūsu lapās',
	'SitesManager_ShowTrackingTag' => 'Apskatīt izsekošanas kodu',
	'SitesManager_NoWebsites' => 'Jums nav nevienas vietnes ko administrēt.',
	'SitesManager_AddSite' => 'Pievienot jaunu vietni',
	'SitesManager_NotFound' => 'Nav atrastas vietnes priekš',
	'SitesManager_Urls' => 'Adreses',
	'SitesManager_MenuSites' => 'Vietnes',
	'SitesManager_DeleteConfirm_js' => 'Vai tiešām vēlaties dzēst vietni %s?',
	'SitesManager_ExceptionNoUrl' => 'Jums jānorāda vismaz viens vietnes URL.',
	'SitesManager_ExceptionEmptyName' => 'Vietnes nosaukums nedrīkst būt tukšs.',
	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' nav pareizs URL.',
	'SitesManager_ExceptionInvalidTimezone' => 'Laika zona "%s" nav pareizi ievadīta. Lūdzu izvēlieties pareizu laika zonu.',
	'SitesManager_ExceptionInvalidCurrency' => 'Valūta "%s" nav pareizi ievadīta. Lūdzu ievadiet pareizu valūtas simbolu (piem., %s)',
	'SitesManager_ExceptionInvalidIPFormat' => 'Izlaižamajai IP "%s" nav pareizs IP formāts (piem., %s).',
	'SitesManager_SuperUserCan' => 'Superlietotājs var arī %s norādīt globālos iestatījumus%s jaunām lapā.',
	'SitesManager_ExcludedIps' => 'Atslēgtās IP adreses',
	'SitesManager_GlobalListExcludedIps' => 'Atslēgto IP adrešu globālais saraksts',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Zemāk esošās IP adreses netiks iekļautas visu vietņu izsekošanā.',
	'SitesManager_ExcludedParameters' => 'Atslēgtie parametri',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Izlaižamo pieprasījuma URL parametru globālais saraksts',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'Zemāk norādītie pieprasījuma URL parametri tiks izlasti no visu vietņu URL.',
	'SitesManager_YourCurrentIpAddressIs' => 'Jūsu pašreizējā IP adrese ir %s',
	'SitesManager_SelectACity' => 'Izvēlieties pilsētu',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Izvēlieties pilsētu vienā laika zonā ar Jums',
	'SitesManager_UTCTimeIs' => 'UTC laiks ir %s.',
	'SitesManager_Timezone' => 'Laika zona',
	'SitesManager_GlobalWebsitesSettings' => 'Globālie vietņu iestatījumi',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Noklusētā laika zona jaunām vietnēm',
	'SitesManager_Currency' => 'Valūta',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Valūtas simbols tiks norādīts blakus mērķu ienākumiem.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Noklusētā valūta jaunām vietnēm',
	'SitesManager_EnableEcommerce' => 'E-komercija ieslēgta',
	'SitesManager_NotAnEcommerceSite' => 'Šī nav e-komercijas vietne',
	'TranslationsAdmin_PluginDescription' => 'Palīdzi iztulkot Piwik savā valodā.',
	'TranslationsAdmin_MenuTranslations' => 'Tulkojumi',
	'TranslationsAdmin_MenuLanguages' => 'Valodas',
	'TranslationsAdmin_LanguageCode' => 'Valodas kods',
	'TranslationsAdmin_Plugin' => 'Spraudnis',
	'TranslationsAdmin_Definition' => 'Definīcija',
	'TranslationsAdmin_DefaultString' => 'Oriģinālais teksts (Angliski)',
	'TranslationsAdmin_TranslationString' => 'Iztulkotais teksts (pašreizējā valoda: %s)',
	'TranslationsAdmin_StatusOfStringsTranslated' => 'Statuss: iztulkoti %1$s no %2$s tekstiem.',
	'TranslationsAdmin_Translations' => 'Tulkojumi',
	'TranslationsAdmin_FixPermissions' => 'Lūdzu salabojiet failsistēmas atļaujas',
	'TranslationsAdmin_AddLanguage' => 'Pievienot valodu',
	'TranslationsAdmin_Export' => 'Eksportēt valodu',
	'TranslationsAdmin_Import' => 'Importēt valodu',
	'TranslationsAdmin_ShowOnlyEmpty' => 'Rādīt tikai iztrūkstošos tulkojumus',
	'TranslationsAdmin_OptionalCountry' => 'Izvēles valsts',
	'TranslationsAdmin_TranslationAlreadyExists' => 'Tulkojums jau pastāv',
	'TranslationsAdmin_CannotOpenForWriting' => 'Nav iespējams atvērt %s rakstīšanai',
	'TranslationsAdmin_InvalidCountry' => 'Nepareiza valsts',
	'TranslationsAdmin_InvalidLanguage' => 'Nepareiza valoda',
	'UserCountry_PluginDescription' => 'Apmeklētāju valstu apskats.',
	'UserCountry_Country' => 'Valsts',
	'UserCountry_Continent' => 'Kontinents',
	'UserCountry_Location' => 'Lokācijas',
	'UserCountry_SubmenuLocations' => 'Lokācijas',
	'UserCountry_country_ac' => 'Debesbraukšanas sala',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_ae' => 'Apvienotie Arābu Emirāti',
	'UserCountry_country_af' => 'Afganistāna',
	'UserCountry_country_ag' => 'Antīkva un Barbuda',
	'UserCountry_country_ai' => 'Angilja',
	'UserCountry_country_al' => 'Albānija',
	'UserCountry_country_am' => 'Armēnija',
	'UserCountry_country_an' => 'Nīderlandes Antiļas',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktīda',
	'UserCountry_country_ar' => 'Argentīna',
	'UserCountry_country_as' => 'Amerikāņu Samoa',
	'UserCountry_country_at' => 'Austrija',
	'UserCountry_country_au' => 'Austrālija',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Ālandu salas',
	'UserCountry_country_az' => 'Azerbaidžāna',
	'UserCountry_country_ba' => 'Bosnija un Hercegovina',
	'UserCountry_country_bb' => 'Barbadosa',
	'UserCountry_country_bd' => 'Bangladeša',
	'UserCountry_country_be' => 'Belģija',
	'UserCountry_country_bf' => 'Burkinafaso',
	'UserCountry_country_bg' => 'Bulgārija',
	'UserCountry_country_bh' => 'Bahreina',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benina',
	'UserCountry_country_bl' => 'Senbartelmī',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneja',
	'UserCountry_country_bo' => 'Bolīvijas Daudznacionālā Valsts',
	'UserCountry_country_bq' => 'Bonaira, Sintēstatiusa un Saba',
	'UserCountry_country_br' => 'Brazīlija',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Butāna',
	'UserCountry_country_bu' => 'Birma',
	'UserCountry_country_bv' => 'Buvē sala',
	'UserCountry_country_bw' => 'Botsvana',
	'UserCountry_country_by' => 'Baltkrievija',
	'UserCountry_country_bz' => 'Beliza',
	'UserCountry_country_ca' => 'Kanāda',
	'UserCountry_country_cc' => 'Kokosu (Kīlinga) salas',
	'UserCountry_country_cd' => 'Kongo Demokrātiskā republika',
	'UserCountry_country_cf' => 'Centrālāfrikas republika',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Šveice',
	'UserCountry_country_ci' => 'Ziloņkaula krasts',
	'UserCountry_country_ck' => 'Kuka salas',
	'UserCountry_country_cl' => 'Čīle',
	'UserCountry_country_cm' => 'Kamerūna',
	'UserCountry_country_cn' => 'Ķīna',
	'UserCountry_country_co' => 'Kolumbija',
	'UserCountry_country_cp' => 'Klipertona sala',
	'UserCountry_country_cr' => 'Kostarika',
	'UserCountry_country_cs' => 'Serbija un Melnkalne',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Kaboverde',
	'UserCountry_country_cw' => 'Karakasa',
	'UserCountry_country_cx' => 'Ziemassvētku sala',
	'UserCountry_country_cy' => 'Kipra',
	'UserCountry_country_cz' => 'Čehija',
	'UserCountry_country_de' => 'Vācija',
	'UserCountry_country_dg' => 'Diego Garsija',
	'UserCountry_country_dj' => 'Džibuti',
	'UserCountry_country_dk' => 'Dānija',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominikāņu republika',
	'UserCountry_country_dz' => 'Alžīrija',
	'UserCountry_country_ea' => 'Ceuta un Melilla',
	'UserCountry_country_ec' => 'Ekvadora',
	'UserCountry_country_ee' => 'Igaunija',
	'UserCountry_country_eg' => 'Ēģipte',
	'UserCountry_country_eh' => 'Rietumsahāra',
	'UserCountry_country_er' => 'Eritreja',
	'UserCountry_country_es' => 'Spānija',
	'UserCountry_country_et' => 'Etiopija',
	'UserCountry_country_eu' => 'Eiropas Savienība',
	'UserCountry_country_fi' => 'Somija',
	'UserCountry_country_fj' => 'Fidži',
	'UserCountry_country_fk' => 'Folklenda (Malvinu) salas',
	'UserCountry_country_fm' => 'Mikronēzijas Federatīvās Valstis',
	'UserCountry_country_fo' => 'Farēru salas',
	'UserCountry_country_fr' => 'Francija',
	'UserCountry_country_fx' => 'Francija (metropole)',
	'UserCountry_country_ga' => 'Gabona',
	'UserCountry_country_gb' => 'Apvienotā Karaliste',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gruzija',
	'UserCountry_country_gf' => 'Franču Gviāna',
	'UserCountry_country_gg' => 'Gērnsija',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gi' => 'Gibrialtārs',
	'UserCountry_country_gl' => 'Grenlande',
	'UserCountry_country_gm' => 'Gambija',
	'UserCountry_country_gn' => 'Gvineja',
	'UserCountry_country_gp' => 'Gvadelupe',
	'UserCountry_country_gq' => 'Ekvatoriālā Gvineja',
	'UserCountry_country_gr' => 'Grieķija',
	'UserCountry_country_gs' => 'Dienviddžordžija un Dienvidsendviču Salas',
	'UserCountry_country_gt' => 'Gvatemala',
	'UserCountry_country_gu' => 'Guama',
	'UserCountry_country_gw' => 'Gvineja-Bisava',
	'UserCountry_country_gy' => 'Gajāna',
	'UserCountry_country_hk' => 'Honkonga',
	'UserCountry_country_hm' => 'Hērda Sala un Makdonalda Salas',
	'UserCountry_country_hn' => 'Hondurasa',
	'UserCountry_country_hr' => 'Horvātija',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Ungārija',
	'UserCountry_country_ic' => 'Kanāriju salas',
	'UserCountry_country_id' => 'Indonēzija',
	'UserCountry_country_ie' => 'Īrija',
	'UserCountry_country_il' => 'Izraēla',
	'UserCountry_country_im' => 'Menas sala',
	'UserCountry_country_in' => 'Indija',
	'UserCountry_country_io' => 'Britu Indijas okeāna teritorija',
	'UserCountry_country_iq' => 'Irāka',
	'UserCountry_country_ir' => 'Irānas Islāma republika',
	'UserCountry_country_is' => 'Īslande',
	'UserCountry_country_it' => 'Itālija',
	'UserCountry_country_je' => 'Džersija',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Jordāna',
	'UserCountry_country_jp' => 'Japāna',
	'UserCountry_country_ke' => 'Kenija',
	'UserCountry_country_kg' => 'Kirgizstāna',
	'UserCountry_country_kh' => 'Kambodža',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komoras',
	'UserCountry_country_kn' => 'Sentkitsa un Nevisa',
	'UserCountry_country_kp' => 'Korejas Demokrātiskā Tautas Republika',
	'UserCountry_country_kr' => 'Korejas Republika',
	'UserCountry_country_kw' => 'Kuveita',
	'UserCountry_country_ky' => 'Kaimanu salas',
	'UserCountry_country_kz' => 'Kazahstāna',
	'UserCountry_country_la' => 'Laosa',
	'UserCountry_country_lb' => 'Libāna',
	'UserCountry_country_lc' => 'Sentlūsija',
	'UserCountry_country_li' => 'Lihtenšteina',
	'UserCountry_country_lk' => 'Šrilanka',
	'UserCountry_country_lr' => 'Libērija',
	'UserCountry_country_ls' => 'Lesoto',
	'UserCountry_country_lt' => 'Lietuva',
	'UserCountry_country_lu' => 'Luksemburga',
	'UserCountry_country_lv' => 'Latvija',
	'UserCountry_country_ly' => 'Lībija',
	'UserCountry_country_ma' => 'Maroka',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldova',
	'UserCountry_country_me' => 'Melnkalne',
	'UserCountry_country_mf' => 'Senmartēna',
	'UserCountry_country_mg' => 'Madagaskara',
	'UserCountry_country_mh' => 'Māršala salas',
	'UserCountry_country_mk' => 'Maķedonija',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Mjanma',
	'UserCountry_country_mn' => 'Mongolija',
	'UserCountry_country_mo' => 'Makau',
	'UserCountry_country_mp' => 'Ziemeļu Marianas salas',
	'UserCountry_country_mq' => 'Martinika',
	'UserCountry_country_mr' => 'Mauritānija',
	'UserCountry_country_ms' => 'Monserata',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Maurīcija',
	'UserCountry_country_mv' => 'Maldīvas',
	'UserCountry_country_mw' => 'Malāvi',
	'UserCountry_country_mx' => 'Meksika',
	'UserCountry_country_my' => 'Malaizija',
	'UserCountry_country_mz' => 'Mozambika',
	'UserCountry_country_na' => 'Namībija',
	'UserCountry_country_nc' => 'Jaunkaledonija',
	'UserCountry_country_ne' => 'Nigēra',
	'UserCountry_country_nf' => 'Norfolka sala',
	'UserCountry_country_ng' => 'Nigērija',
	'UserCountry_country_ni' => 'Nikaragva',
	'UserCountry_country_nl' => 'Nīderlande',
	'UserCountry_country_no' => 'Norvēģija',
	'UserCountry_country_np' => 'Nepāla',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neitrāla zona',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Jaunzēlande',
	'UserCountry_country_om' => 'Omāna',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Franču Polinēzija',
	'UserCountry_country_pg' => 'Papua Jaungvineja',
	'UserCountry_country_ph' => 'Filipīnas',
	'UserCountry_country_pk' => 'Pakistāna',
	'UserCountry_country_pl' => 'Polija',
	'UserCountry_country_pm' => 'Senpjēra un Mikelona',
	'UserCountry_country_pn' => 'Pitkērna',
	'UserCountry_country_pr' => 'Puertoriko',
	'UserCountry_country_ps' => 'Palestīna',
	'UserCountry_country_pt' => 'Portugāle',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paragvaja',
	'UserCountry_country_qa' => 'Katara',
	'UserCountry_country_re' => 'Reinjona',
	'UserCountry_country_ro' => 'Rumānija',
	'UserCountry_country_rs' => 'Serbija',
	'UserCountry_country_ru' => 'Krievijas Federācija',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Saūda Arābija',
	'UserCountry_country_sb' => 'Solomona salas',
	'UserCountry_country_sc' => 'Šeišelas',
	'UserCountry_country_sd' => 'Sudāna',
	'UserCountry_country_se' => 'Zviedrija',
	'UserCountry_country_sf' => 'Somija',
	'UserCountry_country_sg' => 'Singapūra',
	'UserCountry_country_sh' => 'Sv. Helēnas, Debesbraukšanas un Tristana da Kuņas salas',
	'UserCountry_country_si' => 'Slovēnija',
	'UserCountry_country_sj' => 'Svalbāra',
	'UserCountry_country_sk' => 'Slovākija',
	'UserCountry_country_sl' => 'Sjerraleone',
	'UserCountry_country_sm' => 'Sanmarino',
	'UserCountry_country_sn' => 'Senegāla',
	'UserCountry_country_so' => 'Somālija',
	'UserCountry_country_sr' => 'Surinama',
	'UserCountry_country_st' => 'Santome un Prinsipi',
	'UserCountry_country_su' => 'Bijusī PSRS',
	'UserCountry_country_sx' => 'Sintmārtena',
	'UserCountry_country_sv' => 'Salvadora',
	'UserCountry_country_sy' => 'Sīrija',
	'UserCountry_country_sz' => 'Svazilenda',
	'UserCountry_country_ta' => 'Tristana da Kuņas sala',
	'UserCountry_country_tc' => 'Tērksas un Kaikosas salas',
	'UserCountry_country_td' => 'Čada',
	'UserCountry_country_tf' => 'Franču Dienvidu teritorijas',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Taizeme',
	'UserCountry_country_tj' => 'Tadžikistāna',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Austrumtimora',
	'UserCountry_country_tm' => 'Turkmenistāna',
	'UserCountry_country_tn' => 'Tunisija',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Austrumtimora',
	'UserCountry_country_tr' => 'Turcija',
	'UserCountry_country_tt' => 'Trinidada un Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taivāna',
	'UserCountry_country_tz' => 'Tanzānijas Apvienotā Republika',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Apvienotā Karaliste',
	'UserCountry_country_um' => 'ASV Mazās Aizjūras Salas',
	'UserCountry_country_us' => 'Amerikas Savienotās Valstis',
	'UserCountry_country_uy' => 'Urugvaja',
	'UserCountry_country_uz' => 'Uzbekistāna',
	'UserCountry_country_va' => 'Vatikāns',
	'UserCountry_country_vc' => 'Sentvinsenta un Grenadīnas',
	'UserCountry_country_ve' => 'Venecuēlas Bolivāra Republika',
	'UserCountry_country_vg' => 'Britu Virdžīnas',
	'UserCountry_country_vi' => 'ASV Virdžīnas',
	'UserCountry_country_vn' => 'Vjetnama',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Volisa un Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemena',
	'UserCountry_country_yt' => 'Majota',
	'UserCountry_country_yu' => 'Dienvidslāvija',
	'UserCountry_country_za' => 'Dienvidāfrika',
	'UserCountry_country_zm' => 'Zambija',
	'UserCountry_country_zr' => 'Zaira',
	'UserCountry_country_zw' => 'Zimbabve',
	'UserCountry_country_a1' => 'Anonīms starpniekserveris',
	'UserCountry_country_a2' => 'Satelītpieslēgums',
	'UserCountry_country_ap' => 'Āzijas/Klusā okeāna reģions',
	'UserCountry_country_o1' => 'Cita valsts',
	'UserCountry_country_cat' => 'Katalāņu valodā runājošās kopienas',
	'UserCountry_continent_eur' => 'Eiropa',
	'UserCountry_continent_afr' => 'Āfrika',
	'UserCountry_continent_ant' => 'Antarktīda',
	'UserCountry_continent_asi' => 'Āzija',
	'UserCountry_continent_amn' => 'Ziemeļamerika',
	'UserCountry_continent_amc' => 'Centrālamerika',
	'UserCountry_continent_ams' => 'Dienvidamerika',
	'UserCountry_continent_oce' => 'Okeānija',
	'UserCountryMap_map' => 'karte',
	'UserCountryMap_worldMap' => 'Pasaules karte',
	'UserCountryMap_toggleFullscreen' => 'Pārslēgt pilnekrāna režīmu',
	'UserSettings_PluginDescription' => 'Apskata dažādus lietotāju iestatījumus: pārlūku, pārlūku ģimeni, operētājsistēmu, spraudņus, ekrāna izšķirtspēju, globālos iestatījumus.',
	'UserSettings_VisitorSettings' => 'Apmeklētāju iestatījumi',
	'UserSettings_BrowserFamilies' => 'Pārlūku ģimenes',
	'UserSettings_Browsers' => 'Pārlūki',
	'UserSettings_Plugins' => 'Spraudņi',
	'UserSettings_Configurations' => 'Konfigurācijas',
	'UserSettings_WidgetGlobalVisitorsDocumentation' => 'Šajā atskaitē redzamas visbiežāk izmantotās apmeklētāju konfigurācijas. Konfigurācija ir operētājsistēmas, pārlūka tipa un ekrāna izšķirtspējas kombinācija.',
	'UserSettings_WidgetPluginsDocumentation' => 'Šajā atskaitē ir redzami pārlūku spraudņi, kuri bija ieslēgti apmeklētāju pārlūkos. Šī informācija ir svarīga, lai izvēlētos vislabāko veidu kā piegādāt saturu apmeklētājiem.',
	'UserSettings_OperatingSystems' => 'Operētājsistēmas',
	'UserSettings_Resolutions' => 'Ekrāna izšķirtspējas',
	'UserSettings_WideScreen' => 'Platekrāns',
	'UserSettings_ColumnBrowserFamily' => 'Pārlūku ģimene',
	'UserSettings_ColumnBrowser' => 'Pārlūks',
	'UserSettings_ColumnBrowserVersion' => 'Pārlūka versija',
	'UserSettings_ColumnPlugin' => 'Spraudnis',
	'UserSettings_ColumnConfiguration' => 'Konfigurācija',
	'UserSettings_ColumnOperatingSystem' => 'Operētājsistēma',
	'UserSettings_ColumnResolution' => 'Ekrāna izšķirtspēja',
	'UserSettings_ColumnTypeOfScreen' => 'Ekrāna tips',
	'UserSettings_WidgetResolutions' => 'Ekrāna izšķirtspējas',
	'UserSettings_WidgetBrowsers' => 'Apmeklētāju pārlūki',
	'UserSettings_WidgetBrowsersDocumentation' => 'Šajā atskaitē ir informācija par to kādus pārlūkus Jūsu apmeklētāji izmanto. Katra pārlūka versija ir izdalīta atsevišķi.',
	'UserSettings_WidgetPlugins' => 'Spraudņu saraksts',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Piezīme: spraudņu noteikšana nedarbojas Internet Explorer pārlūkā. Šī atskaite ir bāzēta tikai uz ne-IE pārlūkiem.',
	'UserSettings_WidgetWidescreen' => 'Normāls / platekrāns',
	'UserSettings_WidgetBrowserFamilies' => 'Pārlūki pēc ģimenes',
	'UserSettings_WidgetBrowserFamiliesDocumentation' => 'Šis grafiks rāda apmeklētāju pārlūkus izdalītus pa pārlūku ģimenēm. %s Vissvarīgākā informācija tīkla izstrādātājiem ir kādu atveidojuma dzinēju apmeklētāji izmanto. Etiķetes satur dzinēju nosaukumus, kuriem seko visbiežāk izmantotie dzinēji.',
	'UserSettings_WidgetOperatingSystems' => 'Operētājsistēmas',
	'UserSettings_WidgetGlobalVisitors' => 'Globālā apmeklētāju konfigurācija',
	'UserSettings_SubmenuSettings' => 'Iestatījumi',
	'UsersManager_PluginDescription' => 'Piwik lietotāju pārvaldīšana: pievienojiet jaunu lietotāju, labojiet jau esošu, izmainiet pieejas atļaujas. Visas šīs darbības ir pieejamas arī caur API.',
	'UsersManager_UsersManagement' => 'Lietotāju pārvaldīšana',
	'UsersManager_UsersManagementMainDescription' => 'Izveidojiet jaunus vai labojiet esošu lietotāju iestatījumus. Augstāk Jūs varat uzstādīt šo lietotāju pieejas atļaujas.',
	'UsersManager_ThereAreCurrentlyNRegisteredUsers' => 'Pašlaik ir %s reģistrēti lietotāji.',
	'UsersManager_ManageAccess' => 'Pārvaldiet pieejas',
	'UsersManager_MainDescription' => 'Izlemjiet kuriem lietotājiem ir kādas Piwik pieejas atļaujas Jūsu vietnēm. Jūs varat arī uzstādīt pieejas atļaujas visām vietnēm vienlaicīgi.',
	'UsersManager_Sites' => 'Vietnes',
	'UsersManager_AllWebsites' => 'Visas vietnes',
	'UsersManager_ApplyToAllWebsites' => 'Apstipriniet visām vietnēm',
	'UsersManager_User' => 'Lietotājs',
	'UsersManager_PrivNone' => 'Nav pieejas',
	'UsersManager_PrivView' => 'Skatīt',
	'UsersManager_PrivAdmin' => 'Administrēt',
	'UsersManager_ChangeAllConfirm' => 'Vai tiešām vēlaties mainīt \'%s\' pieejas atļaujas visām vietnēm?',
	'UsersManager_ChangePasswordConfirm' => 'Mainot lietotāja paroli, tiks izmainīts arī lietotāja token_auth. Vai tiešām vēlaties turpināt?',
	'UsersManager_Password' => 'Parole',
	'UsersManager_Email' => 'E-pasta adrese',
	'UsersManager_Alias' => 'Aizstājējvārds',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Superlietotāja aizstājējvārdu nav iespējams izmainīt.',
	'UsersManager_ReportToLoadByDefault' => 'Atskaite, kuru ielādēt pēc noklusējuma',
	'UsersManager_ReportDateToLoadByDefault' => 'Atskaites datums, kuru ielādēt pēc noklusējuma',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Atskaite, kuru ielādēt pēc noklusējuma anonīmiem lietotājiem',
	'UsersManager_ExcludeVisitsViaCookie' => 'Neiekļaut Jūsu pašu apmeklējumus izmantojot sīkdatni',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sJūsu apmeklējumi tiek ignorēti %s %s (pārlūkā tika atrasta Piwik ignorēšanas sīkdatne).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Klikšķiniet šeit, lai dzēstu sīkdatni un atļautu Piwik izsekot Jūsu pašu apmeklējumus',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Klikšķiniet šeit, lai iestatītu sīkdatni, kas aizliegs izsekot Jūsu pašu apmeklējumus %s',
	'UsersManager_Edit' => 'Labot',
	'UsersManager_AddUser' => 'Pievienot jaunu lietotāju',
	'UsersManager_MenuUsers' => 'Lietotāji',
	'UsersManager_MenuUserSettings' => 'Lietotāju iestatījumi',
	'UsersManager_MenuAnonymousUserSettings' => 'Anonīmu lietotāju iestatījumi',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Kad lietotāji nav pieteikušies un apmeklē Piwik, tiem rādam',
	'UsersManager_ChangePassword' => 'Mainīt paroli',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Ja vēlaties mainīt paroli, ievadiet jauno. Pretējā gadījumā atstājiet tukšu.',
	'UsersManager_TypeYourPasswordAgain' => 'Ierakstiet savu jauno paroli atkārtoti.',
	'UsersManager_TheLoginScreen' => 'Pieteikšanās skats',
	'UsersManager_DeleteConfirm_js' => 'Vai Jūs tiešām vēlaties dzēst lietotāju %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Jūsu lietotājvārdu nav iespējams izmainīt.',
	'UsersManager_ExceptionLoginExists' => 'Lietotājvārds \'%s\' jau eksistē.',
	'UsersManager_ExceptionEmailExists' => 'Lietotājs ar e-pasta adresi \'%s\' jau eksistē.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Lietotājvārdam jābūt garumā no %1$s līdz %2$s simboliem un jāsatur tikai cipari, burti vai simboli \'_\', \'-\', \'.\', \'@\', \'+\'',
	'UsersManager_ExceptionInvalidPassword' => 'Parolei jābūt garumā no %1$s līdz %2$s simboliem.',
	'UsersManager_ExceptionInvalidEmail' => 'E-pasta adresei nav pareizs formāts',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Lietotāju \'%s\' nevar izdzēst, jo tāds neeksistē.',
	'UsersManager_ExceptionAdminAnonymous' => 'Jūs nevarat atļaut administrēšanas pieeju anonīmiem lietotājiem.',
	'UsersManager_ExceptionEditAnonymous' => 'Anonīmo lietotāju nav iespējams labot vai dzēst. Tas tiek izmantots, lai definētu lietotāju, kurš vēl nav pieteicies. Piemēram, Jūs varat publiskot statistiku atļaujot apskates pieeju anonīmajam lietotājam.',
	'UsersManager_ExceptionSuperUser' => 'Pieprasītais lietotājs ir superlietotājs, kuru nav iespējams pieprasīt, labot vai dzēst izmantojot API. Jūs varat šī lietotāja datus manuāli labot Piwik iestatījumu datnē.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Lietotājs \'%s\' neeksistē.',
	'UsersManager_ExceptionAccessValues' => 'Pieejas parametriem jāsatur kāda no šīm vērtībām: [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth sagaida MD5 kodētu paroli (32 simbolu garu tekstu). Lūdzu pielietojiet md5() metodi parolei pirms izsaucat šo metodi.',
	'VisitFrequency_ColumnReturningVisits' => 'Atkārtoti apmeklējumi',
	'VisitFrequency_ReturningVisitsDocumentation' => 'Šis ir atkārtotu apmeklējumu pārskats.',
	'VisitFrequency_ColumnUniqueReturningVisitors' => 'Unikālie atkārtotie apmeklētāji',
	'VisitFrequency_WidgetOverview' => 'Biežuma pārskats',
	'VisitFrequency_SubmenuFrequency' => 'Biežums',
	'VisitorGenerator_ChoiceYes' => 'Jā, es esmu drošs!',
	'VisitorGenerator_Submit' => 'Apstiprināt',
	'VisitorGenerator_SelectWebsite' => 'Izvēlēties vietni',
	'VisitorInterest_VisitsPerDuration' => 'Apmeklējumi pēc apmeklējuma ilguma',
	'VisitorInterest_VisitsPerNbOfPages' => 'Apmeklējumi pēc lapu skaita',
	'VisitorInterest_ColumnVisitDuration' => 'Apmeklējuma ilgums',
	'VisitorInterest_ColumnPagesPerVisit' => 'Lapas apmeklējumā',
	'VisitorInterest_visitsByVisitCount' => 'Apmeklējumu pēc apmeklējuma numura',
	'VisitorInterest_VisitNum' => 'Apmeklējuma numurs',
	'VisitorInterest_WidgetLengths' => 'Apmeklējumu garums',
	'VisitorInterest_WidgetPages' => 'Lapas apmeklējumā',
	'VisitorInterest_OneMinute' => '1 min.',
	'VisitorInterest_PlusXMin' => '%s min.',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s min.',
	'VisitorInterest_OnePage' => '1 lapa',
	'VisitorInterest_NPages' => '%s lapas',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_NbVisits' => '%s apmeklējumi',
	'VisitsSummary_NbUniqueVisitors' => '%s unikāli apmeklētāji',
	'VisitsSummary_NbActionsDescription' => '%s darbības',
	'VisitsSummary_NbPageviewsDescription' => '%s lapu skatījumi',
	'VisitsSummary_NbUniquePageviewsDescription' => '%s unikāli lapu skatījumi',
	'VisitsSummary_NbDownloadsDescription' => '%s lejupielādes',
	'VisitsSummary_NbUniqueDownloadsDescription' => '%s unikālas lejupielādes',
	'VisitsSummary_NbOutlinksDescription' => '%s ārējas saites',
	'VisitsSummary_NbUniqueOutlinksDescription' => '%s unikālas ārējas saites',
	'VisitsSummary_AverageVisitDuration' => '%s vidējais apmekējuma garums',
	'VisitsSummary_MaxNbActions' => '%s maks. darbības vienā apmeklējumā',
	'VisitsSummary_NbActionsPerVisit' => '%s darbības (lapu skatījumi, lejupielādes un ārējas saites) apmeklējumā',
	'VisitsSummary_WidgetLastVisits' => 'Pēdējo apmeklējumu grafiks',
	'VisitsSummary_WidgetVisits' => 'Apmeklējumu pārskats',
	'VisitsSummary_SubmenuOverview' => 'Pārskats',
	'VisitTime_LocalTime' => 'Apmeklējumi pēc vietējā laika',
	'VisitTime_ServerTime' => 'Apmeklējumi pēc servera laika',
	'VisitTime_ColumnServerTime' => 'Servera laiks',
	'VisitTime_ColumnLocalTime' => 'Lokālais laiks',
	'VisitTime_WidgetLocalTime' => 'Apmeklējumi pēc lokālā laika',
	'VisitTime_SubmenuTimes' => 'Laiki',
	'VisitTime_NHour' => '%s st.',
	'PDFReports_EmailReports' => 'E-pasta atskaites',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Sūtīt atskaiti tagad',
	'PDFReports_SendReportTo' => 'Sūtīt atskaites uz',
	'PDFReports_ReportFormat' => 'Atskaites formāts',
	'PDFReports_SentToMe' => 'Sūtīt man',
	'PDFReports_ReportsIncluded' => 'Iekļautā statistika',
	'PDFReports_CreateReport' => 'Izveidot atskaiti',
	'PDFReports_UpdateReport' => 'Atjaunināt atskaiti',
	'PDFReports_PiwikReports' => 'Piwik atskaites',
	'PDFReports_DefaultContainingAllReports' => 'Noklusējuma atskaite satur visu pieejamo statistiku.',
	'PDFReports_EmailHello' => 'Sveiki,',
	'PDFReports_FrontPage' => 'Pirmā lapa',
	'PDFReports_TableOfContent' => 'Atskaišu saraksts',
	'PDFReports_TopOfReport' => 'Atpakaļ uz sākumu',
	'PDFReports_Pagination' => '%s. lapa no %s',
	'ImageGraph_PluginDescription' => 'Ģenerējiet skaistus, statiskus PNG formāta grafikus jebkurai Piwik atskaitei.',
);
